@@ -786,7 +786,6 @@ if platform.system() == "Windows":
             OSSortKeyType, lambda x: tuple(map(_winsort_key, _split_apply(x, key)))
         )
 
-
 else:
 
     # For UNIX-based platforms, ICU performs MUCH better than locale
@@ -877,7 +876,7 @@ def os_sorted(
     .. warning::
 
         The resulting function will generate results that will be
-        differnt depending on your platform. This is intentional.
+        different depending on your platform. This is intentional.
 
     On Windows, this will sort with the same order as Windows Explorer.
 
@@ -893,7 +892,7 @@ def os_sorted(
       special characters this will give correct results, but once
       special characters are added you should lower your expectations.
 
-    It is *strongly* reccommended to have :mod:`pyicu` installed on
+    It is *strongly* recommended to have :mod:`pyicu` installed on
     MacOS/Linux if you want correct sort results.
 
     It does *not* take into account if a path is a directory or a file
